# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 0.44.00-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into sdk package
from .models.ace_input_v1 import AceInputV1
from .models.ace_output_v1 import AceOutputV1
from .models.acl_output_v1 import AclOutputV1
from .models.administrator_contact_information_v1 import AdministratorContactInformationV1
from .models.agent_key_output_v1 import AgentKeyOutputV1
from .models.agent_status_v1 import AgentStatusV1
from .models.ancillary_input_v1 import AncillaryInputV1
from .models.ancillary_item_input_v1 import AncillaryItemInputV1
from .models.ancillary_item_output_v1 import AncillaryItemOutputV1
from .models.ancillary_output_v1 import AncillaryOutputV1
from .models.annotation_input_v1 import AnnotationInputV1
from .models.annotation_interest_input_v1 import AnnotationInterestInputV1
from .models.annotation_interest_output_v1 import AnnotationInterestOutputV1
from .models.annotation_list_output_v1 import AnnotationListOutputV1
from .models.annotation_output_v1 import AnnotationOutputV1
from .models.archive_signal_output_v1 import ArchiveSignalOutputV1
from .models.asset_batch_input_v1 import AssetBatchInputV1
from .models.asset_input_v1 import AssetInputV1
from .models.asset_output_v1 import AssetOutputV1
from .models.asset_tree_batch_input_v1 import AssetTreeBatchInputV1
from .models.asset_tree_output_v1 import AssetTreeOutputV1
from .models.asset_tree_single_input_v1 import AssetTreeSingleInputV1
from .models.auth_input_v1 import AuthInputV1
from .models.auth_providers_output_v1 import AuthProvidersOutputV1
from .models.base_acl_output import BaseAclOutput
from .models.cache_info_v1 import CacheInfoV1
from .models.calculated_item_input_v1 import CalculatedItemInputV1
from .models.calculated_item_output_v1 import CalculatedItemOutputV1
from .models.capsule_v1 import CapsuleV1
from .models.capsules_input_v1 import CapsulesInputV1
from .models.capsules_output_v1 import CapsulesOutputV1
from .models.channel_output_v1 import ChannelOutputV1
from .models.condition_batch_input_v1 import ConditionBatchInputV1
from .models.condition_input_v1 import ConditionInputV1
from .models.condition_output_v1 import ConditionOutputV1
from .models.connection_status_v1 import ConnectionStatusV1
from .models.counter_datum_v1 import CounterDatumV1
from .models.datasource_clean_up_input_v1 import DatasourceCleanUpInputV1
from .models.datasource_clean_up_output_v1 import DatasourceCleanUpOutputV1
from .models.datasource_input_v1 import DatasourceInputV1
from .models.datasource_output_list_v1 import DatasourceOutputListV1
from .models.datasource_output_v1 import DatasourceOutputV1
from .models.document_backup_output_v1 import DocumentBackupOutputV1
from .models.example_model import ExampleModel
from .models.export_item_v1 import ExportItemV1
from .models.export_items_v1 import ExportItemsV1
from .models.folder_input_v1 import FolderInputV1
from .models.folder_output_list_v1 import FolderOutputListV1
from .models.folder_output_v1 import FolderOutputV1
from .models.formula_compile_output_v1 import FormulaCompileOutputV1
from .models.formula_error_output_v1 import FormulaErrorOutputV1
from .models.formula_input_v1 import FormulaInputV1
from .models.formula_log_entry import FormulaLogEntry
from .models.formula_log_entry_details import FormulaLogEntryDetails
from .models.formula_log_v1 import FormulaLogV1
from .models.formula_parameter_input_v1 import FormulaParameterInputV1
from .models.formula_parameter_output_v1 import FormulaParameterOutputV1
from .models.formula_run_input_v1 import FormulaRunInputV1
from .models.formula_run_output_v1 import FormulaRunOutputV1
from .models.formula_token import FormulaToken
from .models.function_group_model import FunctionGroupModel
from .models.function_input_v1 import FunctionInputV1
from .models.function_model import FunctionModel
from .models.gauge_datum_v1 import GaugeDatumV1
from .models.generic_table_output_v1 import GenericTableOutputV1
from .models.get_channels_output_v1 import GetChannelsOutputV1
from .models.get_jobs_output_v1 import GetJobsOutputV1
from .models.get_metrics_output_v1 import GetMetricsOutputV1
from .models.get_requests_output_v1 import GetRequestsOutputV1
from .models.get_sample_output_v1 import GetSampleOutputV1
from .models.get_samples_output_v1 import GetSamplesOutputV1
from .models.get_signals_output_v1 import GetSignalsOutputV1
from .models.identity_preview_list_v1 import IdentityPreviewListV1
from .models.identity_preview_v1 import IdentityPreviewV1
from .models.importer_file_list_output_v1 import ImporterFileListOutputV1
from .models.importer_output_v1 import ImporterOutputV1
from .models.input_stream import InputStream
from .models.item_ancillary_output_v1 import ItemAncillaryOutputV1
from .models.item_batch_output_v1 import ItemBatchOutputV1
from .models.item_dependency_output_v1 import ItemDependencyOutputV1
from .models.item_id_list_input_v1 import ItemIdListInputV1
from .models.item_output_v1 import ItemOutputV1
from .models.item_parameter_of_output_v1 import ItemParameterOfOutputV1
from .models.item_preview_list_v1 import ItemPreviewListV1
from .models.item_preview_v1 import ItemPreviewV1
from .models.item_preview_with_assets_v1 import ItemPreviewWithAssetsV1
from .models.item_search_preview_list_v1 import ItemSearchPreviewListV1
from .models.item_search_preview_paginated_list_v1 import ItemSearchPreviewPaginatedListV1
from .models.item_search_preview_v1 import ItemSearchPreviewV1
from .models.item_update_output_v1 import ItemUpdateOutputV1
from .models.job_output_v1 import JobOutputV1
from .models.license_importer_output_v1 import LicenseImporterOutputV1
from .models.license_status_output_v1 import LicenseStatusOutputV1
from .models.licensed_feature_status_output_v1 import LicensedFeatureStatusOutputV1
from .models.meter_datum_v1 import MeterDatumV1
from .models.monitor_input_v1 import MonitorInputV1
from .models.parameter_model import ParameterModel
from .models.parameter_signature_model import ParameterSignatureModel
from .models.priority_v1 import PriorityV1
from .models.progress_information_output_v1 import ProgressInformationOutputV1
from .models.property_href_output_v1 import PropertyHrefOutputV1
from .models.property_input_v1 import PropertyInputV1
from .models.property_output_v1 import PropertyOutputV1
from .models.put_samples_input_v1 import PutSamplesInputV1
from .models.put_samples_output_v1 import PutSamplesOutputV1
from .models.put_scalars_input_v1 import PutScalarsInputV1
from .models.put_signals_input_v1 import PutSignalsInputV1
from .models.regression_output_v1 import RegressionOutputV1
from .models.report_input_item_v1 import ReportInputItemV1
from .models.report_input_v1 import ReportInputV1
from .models.request_output_v1 import RequestOutputV1
from .models.sample_input_v1 import SampleInputV1
from .models.sample_output_v1 import SampleOutputV1
from .models.scalar_input_v1 import ScalarInputV1
from .models.scalar_property_v1 import ScalarPropertyV1
from .models.scalar_value_output_v1 import ScalarValueOutputV1
from .models.screenshot_job_input_v1 import ScreenshotJobInputV1
from .models.screenshot_output_v1 import ScreenshotOutputV1
from .models.see_also_model import SeeAlsoModel
from .models.send_logs_input_v1 import SendLogsInputV1
from .models.series_batch_input_v1 import SeriesBatchInputV1
from .models.series_input_v1 import SeriesInputV1
from .models.series_output_v1 import SeriesOutputV1
from .models.series_sample_v1 import SeriesSampleV1
from .models.series_samples_input_v1 import SeriesSamplesInputV1
from .models.series_samples_output_v1 import SeriesSamplesOutputV1
from .models.server_spec_output_v1 import ServerSpecOutputV1
from .models.server_status_output_v1 import ServerStatusOutputV1
from .models.signal_input_v1 import SignalInputV1
from .models.signal_output_v1 import SignalOutputV1
from .models.signal_with_id_input_v1 import SignalWithIdInputV1
from .models.status_message_base import StatusMessageBase
from .models.subscription_input_v1 import SubscriptionInputV1
from .models.subscription_output_v1 import SubscriptionOutputV1
from .models.subscription_parameter_output_v1 import SubscriptionParameterOutputV1
from .models.subscription_update_input_v1 import SubscriptionUpdateInputV1
from .models.swap_input_v1 import SwapInputV1
from .models.sync_progress import SyncProgress
from .models.system_configuration_input_v1 import SystemConfigurationInputV1
from .models.system_configuration_output_v1 import SystemConfigurationOutputV1
from .models.table_column_output_v1 import TableColumnOutputV1
from .models.table_output_v1 import TableOutputV1
from .models.threshold_metric_input_v1 import ThresholdMetricInputV1
from .models.threshold_metric_output_v1 import ThresholdMetricOutputV1
from .models.threshold_output_v1 import ThresholdOutputV1
from .models.timer_datum_v1 import TimerDatumV1
from .models.tree_item_output_v1 import TreeItemOutputV1
from .models.treemap_item_output_v1 import TreemapItemOutputV1
from .models.treemap_output_v1 import TreemapOutputV1
from .models.user_group_input_v1 import UserGroupInputV1
from .models.user_group_output_v1 import UserGroupOutputV1
from .models.user_input_v1 import UserInputV1
from .models.user_output_list_v1 import UserOutputListV1
from .models.user_output_v1 import UserOutputV1
from .models.user_password_input_v1 import UserPasswordInputV1
from .models.user_update_v1 import UserUpdateV1
from .models.workbook_input_v1 import WorkbookInputV1
from .models.workbook_output_list_v1 import WorkbookOutputListV1
from .models.workbook_output_v1 import WorkbookOutputV1
from .models.worksheet_input_v1 import WorksheetInputV1
from .models.worksheet_output_list_v1 import WorksheetOutputListV1
from .models.worksheet_output_v1 import WorksheetOutputV1
from .models.workstep_input_v1 import WorkstepInputV1
from .models.workstep_output_v1 import WorkstepOutputV1

# import apis into sdk package
from .apis.agents_api import AgentsApi
from .apis.ancillaries_api import AncillariesApi
from .apis.annotations_api import AnnotationsApi
from .apis.assets_api import AssetsApi
from .apis.auth_api import AuthApi
from .apis.conditions_api import ConditionsApi
from .apis.datasources_api import DatasourcesApi
from .apis.folders_api import FoldersApi
from .apis.formulas_api import FormulasApi
from .apis.import_api import ImportApi
from .apis.items_api import ItemsApi
from .apis.jobs_api import JobsApi
from .apis.logs_api import LogsApi
from .apis.metrics_api import MetricsApi
from .apis.monitors_api import MonitorsApi
from .apis.networks_api import NetworksApi
from .apis.reports_api import ReportsApi
from .apis.requests_api import RequestsApi
from .apis.sample_series_api import SampleSeriesApi
from .apis.scalars_api import ScalarsApi
from .apis.signals_api import SignalsApi
from .apis.subscriptions_api import SubscriptionsApi
from .apis.system_api import SystemApi
from .apis.tables_api import TablesApi
from .apis.trees_api import TreesApi
from .apis.user_groups_api import UserGroupsApi
from .apis.users_api import UsersApi
from .apis.workbooks_api import WorkbooksApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()



import pytest

import pandas as pd

from seeq import spy

from . import test_common


@pytest.mark.system
def test_pull_signal():
    test_common.login()

    search_results = spy.search({
        "Path": "Example >> Cooling Tower 1 >> Area A"
    })

    search_results = search_results.loc[
        search_results['Name'].isin(['Compressor Power', 'Temperature', 'Relative Humidity'])]

    spy.pull(search_results, start='2019-01-01', end='2019-03-07', grid='5min', header='Name')


@pytest.mark.system
def test_pull_condition_as_capsules():
    test_common.login()

    search_results = spy.search({
        'Name': 'Area A_Temperature'
    })

    push_result = spy.push(metadata=pd.DataFrame([{
        'Type': 'Condition',
        'Name': 'Hot',
        'Formula': '$a.validValues().valueSearch(isGreaterThan(80))',
        'Formula Parameters': {
            '$a': search_results.iloc[0]
        }
    }]))

    spy.pull(push_result.iloc[0], start='2019-01-01T00:00:00.000Z', end='2019-06-01T00:00:00.000Z')


@pytest.mark.system
def test_pull_condition_as_signal():
    test_common.login()

    search_results = spy.search({
        'Name': 'Area A_Temperature'
    })

    push_result = spy.push(metadata=pd.DataFrame([{
        'Type': 'Condition',
        'Name': 'Hot',
        'Formula': '$a.validValues().valueSearch(isGreaterThan(80))',
        'Formula Parameters': {
            '$a': search_results.iloc[0]
        }
    }]))

    spy.pull(push_result.iloc[0], start='2019-01-01T00:00:00.000Z', end='2019-06-01T00:00:00.000Z',
             capsules_as='signals')



import pytest

from seeq import spy
from seeq.spy.assets import Asset

from . import test_common


class HVAC(Asset):

    @Asset.Attribute()
    def Temperature(self, metadata):
        # We use simple Pandas syntax to select for a row in the DataFrame corresponding to our desired tag
        return metadata[metadata['Name'].str.endswith('Temperature')]

    @Asset.Attribute()
    def Relative_Humidity(self, metadata):
        # All Attribute functions must take (self, metadata) as parameters
        return metadata[metadata['Name'].str.contains('Humidity')]


class Compressor(Asset):

    @Asset.Attribute()
    def Power(self, metadata):
        return metadata[metadata['Name'].str.endswith('Power')]


class HVAC_With_Calcs(HVAC):

    @Asset.Attribute()
    def Temperature_Rate_Of_Change(self, metadata):
        return {
            'Type': 'Signal',

            # This formula will give us a nice derivative in F/h
            'Formula': '$temp.lowPassFilter(150min, 3min, 333).derivative() * 3600 s/h',

            'Formula Parameters': {
                # We can reference the base class' Temperature attribute here as a dependency
                '$temp': self.Temperature(metadata),
            }
        }

    @Asset.Attribute()
    def Too_Hot(self, metadata):
        return {
            'Type': 'Condition',
            'Formula': '$temp.valueSearch(isGreaterThan($threshold))',
            'Formula Parameters': {
                '$temp': self.Temperature(metadata),

                # We can also reference other attributes in this derived class
                '$threshold': self.Hot_Threshold(metadata)
            }
        }

    @Asset.Attribute()
    def Hot_Threshold(self, metadata):
        return {
            'Type': 'Scalar',
            'Formula': '80F'
        }

    # Designating a function as a Component allows you to include a child asset with its own set of attributes
    @Asset.Component()
    def Compressor(self, metadata):
        return Compressor


@pytest.mark.system
def test_instantiate():
    test_common.login()

    hvac_metadata_df = spy.search({
        'Name': 'Area ?_*'
    })

    hvac_metadata_df['Instance Template'] = 'HVAC'

    hvac_metadata_df['Instance Asset'] = hvac_metadata_df['Name'].str.extract('(Area .)_.*')

    hvac_metadata_df['Instance Path'] = 'My HVAC Units >> Facility #1'

    instances_df = spy.assets.instantiate(HVAC, hvac_metadata_df)

    spy.push(metadata=instances_df)

    hvac_with_calcs_metadata_df = hvac_metadata_df.copy()
    hvac_with_calcs_metadata_df['Instance Template'] = 'HVAC_With_Calcs'

    instances_with_calcs_df = spy.assets.instantiate(HVAC_With_Calcs, hvac_with_calcs_metadata_df)

    spy.push(metadata=instances_with_calcs_df)



import pytest

import pandas as pd

from seeq import spy

from . import test_common

from .. import _common


def setup_module():
    test_common.login()


@pytest.mark.system
def test_simple_search():
    search_results = spy.search({
        'Name': 'Area A_Temper'
    })

    assert len(search_results) == 1

    search_results = spy.search(pd.DataFrame([{
        'Name': 'Area A_Temper'
    }]))

    # Nothing will be returned because we use a equal-to comparison when a DataFrame is passed in
    assert len(search_results) == 0

    search_results = spy.search(pd.DataFrame([{
        'Name': 'Area A_Temperature'
    }]))

    assert len(search_results) == 1


@pytest.mark.system
def test_type_search():
    search_results = spy.search({
        'Datasource Class': 'Time Series CSV Files',
        'Type': 'Signal'
    })

    assert 150 < len(search_results) < 200

    datasource_names = set(search_results['Datasource Name'].tolist())
    assert len(datasource_names) == 1
    assert datasource_names.pop() == 'Example Data'

    types = set(search_results['Type'].tolist())
    assert len(types) == 1
    assert types.pop() == 'StoredSignal'

    search_results = spy.search({
        'Datasource Class': 'Time Series CSV Files',
        'Type': 'Condition'
    })

    assert len(search_results) == 0

    search_results = spy.search({
        'Datasource Class': 'Time Series CSV Files',
        'Type': 'Scalar'
    })

    assert len(search_results) == 0


@pytest.mark.system
def test_path_search():
    with pytest.raises(RuntimeError):
        spy.search({
            'Path': 'Non-existent >> Path'
        })

    search_results = spy.search({
        'Path': 'Example >> Cooling Tower 1'
    })

    assert 40 < len(search_results) < 60


@pytest.mark.system
def test_datasource_name_search():
    with pytest.raises(RuntimeError):
        spy.search({
            'Datasource Name': 'Non-existent'
        })

    search_results = spy.search({
        'Datasource Name': 'Example Data'
    })

    assert 150 < len(search_results) < 200


@pytest.mark.system
def test_search_pagination():
    original_page_size = _common.DEFAULT_SEARCH_PAGE_SIZE
    try:
        _common.DEFAULT_SEARCH_PAGE_SIZE = 2
        search_results = spy.search({
            'Name': 'Area A_*'
        })

        assert len(search_results) == 6

    finally:
        _common.DEFAULT_SEARCH_PAGE_SIZE = original_page_size



import pytest

import pandas as pd

from seeq import spy

from . import test_common


@pytest.mark.system
def test_push_signal():
    test_common.login()

    push_df = pd.DataFrame(pd.Series([
        1,
        2,
        3
    ], index=[
        pd.to_datetime('2019-01-01'),
        pd.to_datetime('2019-01-02'),
        pd.to_datetime('2019-01-03')
    ]), columns=['My Signal'])

    spy.push(push_df)
